# RStudio ver 1.1.383
# Figure #'s refer to figures and tables in:
# 'Planting Date Effects on Cotton Lint Yield and Fiber Quality  in the U.S. Southern High Plains'
#
library(dplyr)
library(stats)
library(base)
library(readxl)
# 
setwd('/Your_Current_Directory')
# 
# May Planted Yields
yld    <- read_excel("LBKYield2007-2017.xlsx", col_names=TRUE, sheet=1) 
# June Planted Yields
yld_lp <- read_excel("LBKYield2007-2017.xlsx", col_names=TRUE, sheet=2) 
# Inner join identifys yields for cultivars planted each year in May and June
# See common yields row of Table 2, Common Yield Tab of LBKYield2007-2017.xlsx
yld_fx <- inner_join(yld,yld_lp, by = c("year","cult") ) 
#
# Force numeric types 
yld_fx <- yld_fx %>% mutate(pct_open = as.numeric(pct_open_boll))
yld_fx <- yld_fx %>% mutate(pct_open_lp = as.numeric(pct_open_boll_lp))
yld_fx <- yld_fx %>% mutate(strm_resis_lp = as.numeric(strm_resis_lp))
yld_fx <- yld_fx %>% mutate(lnt_pct_pull = as.numeric(lnt_pct_pull))
yld_fx <- yld_fx %>% mutate(lnt_pct_pick = as.numeric(lnt_pct_pick))
yld_fx <- yld_fx %>% mutate(hgt = as.numeric(hgt))
yld_fx <- yld_fx %>% mutate(hgt_lp = as.numeric(hgt_lp))
yld_fx <- yld_fx %>% mutate(yld = as.numeric(yld))
yld_fx <- yld_fx %>% mutate(yld_lp = as.numeric(yld_lp))
# Calculate May-June effects and columns to yld_fx data frame
yld_fx <- yld_fx %>% mutate(delhgt = hgt-hgt_lp)
yld_fx <- yld_fx %>% mutate(delyld = yld-yld_lp)
yld_fx <- yld_fx %>% mutate(delgdd = gdd-gdd_lp)
yld_fx <- yld_fx %>% mutate(delpctopen = pct_open-pct_open_lp)
yld_fx <- yld_fx %>% mutate(gddeffect = delyld/delgdd)
#
# Selecting data frame columns to write to yieldefx.log
# Figs. 3 & 4 plotted from yieldefx.log via Generic Mapping Tools
columns <- c('year','yld','yld_lp','gdd','gdd_lp','delyld','delgdd','gddeffect','cult')
sub_yld_fx <- select(yld_fx,columns) 
write.table(sub_yld_fx,file="yieldefx.log",quote=FALSE)
#
# Calculate mean yield effect for each year in Fig 3f
Fig3f <- yld_fx %>% group_by(year) %>% summarize(avg = mean(delyld))
write.table(Fig3f,file="Fig3f.log",quote=FALSE)
#
# T tests for each year in Fig. 3f calculated for each year on console.
temp <- yld_fx %>% filter(year == 2007,2008,...2017)
t.test(temp$delyld,mu=0.0,alternative="two.sided",conf.level=0.95)
# 
# year delyld avg    p-value ###
# 2007   172.8       0.003151
# 2008   607.2       2.002e-07
# 2009   542.3       7.677e-07
# 2010   598.7       4.206e-11
# 2011    97.9       0.001784
# 2012   231.0       0.0008617
# 2013   359.1       2.962-e08
# 2015   -89.9       0.0001638
# 2016  -185.5       0.002034
# 2017   561.4       2.2e-16
#
